=========
Changelog
=========



Version 0.0.1b5 2019-02-14
==========================

- Update README
- Fix uploading token
- Fix creating new drafts records (filebucketid)

Version 0.0.1b4 2019-02-12
==========================

- Fixed bug in adding files to records

Version 0.0.1-a0
================

- Added first basic methods

